@@ -90,15 +90,16 @@ async fn main() -> Result<()> {
         file_config.clear_data || command_line_args.clear_data
     );
 
-    if command_line_args.local_addr.is_some() || command_line_args.first.is_some() {
-        assert_eq!(
-            command_line_args.first.or(command_line_args.local_addr),
-            config.local_addr
-        );
+    if command_line_args.local_addr.is_some() {
+        assert_eq!(command_line_args.local_addr, config.local_addr);
     } else {
         assert_eq!(file_config.local_addr, config.local_addr);
     }
 
+    if command_line_args.first {
+        assert!(config.first);
+    }
+
     if command_line_args.public_addr.is_some() {
         assert_eq!(command_line_args.public_addr, config.public_addr);
     } else {
@@ -166,15 +167,6 @@ async fn main() -> Result<()> {
         )
     }
 
-    if command_line_args.bootstrap_cache_dir.is_some() {
-        assert_eq!(
-            command_line_args.bootstrap_cache_dir,
-            config.bootstrap_cache_dir
-        )
-    } else {
-        assert_eq!(file_config.bootstrap_cache_dir, config.bootstrap_cache_dir)
-    }
-
     if command_line_args.upnp_lease_duration.is_some() {
         assert_eq!(
             command_line_args
