@@ -19,8 +19,8 @@ pub(crate) use self::{
     proposal::{ProposalAggregator, ProposalError, ProposalUtils},
     voter::DkgVoter,
 };
-pub(crate) use crate::messaging::node::{KeyedSig, SigShare};
-pub(super) use section_signed::SectionAuthUtils;
+pub(crate) use crate::messaging::system::{KeyedSig, SigShare};
+pub use section_signed::SectionAuthUtils;
 use serde::Serialize;
 
 // Verify the integrity of `message` against `sig`.
